@@ -1,5 +1,5 @@
 package Image::PNG::Const;
-our $VERSION = '0.29';
+our $VERSION = '0.30';
 
 require Exporter;
 @ISA = qw(Exporter);
@@ -108,6 +108,12 @@ PNG_DEFAULT_sRGB
 PNG_GAMMA_MAC_18
 PNG_GAMMA_sRGB
 PNG_GAMMA_LINEAR
+PNG_FILLER_BEFORE
+PNG_FILLER_AFTER
+PNG_BACKGROUND_GAMMA_UNKNOWN
+PNG_BACKGROUND_GAMMA_SCREEN
+PNG_BACKGROUND_GAMMA_FILE
+PNG_BACKGROUND_GAMMA_UNIQUE
 PNG_READ_16_TO_8
 PNG_GAMMA_THRESHOLD
 PNG_CRC_DEFAULT
@@ -151,6 +157,15 @@ PNG_HANDLE_CHUNK_AS_DEFAULT
 PNG_HANDLE_CHUNK_NEVER
 PNG_HANDLE_CHUNK_IF_SAFE
 PNG_HANDLE_CHUNK_ALWAYS
+PNG_IO_NONE
+PNG_IO_READING
+PNG_IO_WRITING
+PNG_IO_SIGNATURE
+PNG_IO_CHUNK_HDR
+PNG_IO_CHUNK_DATA
+PNG_IO_CHUNK_CRC
+PNG_IO_MASK_OP
+PNG_IO_MASK_LOC
 PNG_INTERLACE_ADAM7_PASSES
 /;
 
@@ -269,6 +284,12 @@ use constant {
     PNG_GAMMA_MAC_18 => -2,
     PNG_GAMMA_sRGB => 220000,
     PNG_GAMMA_LINEAR => 100000,
+    PNG_FILLER_BEFORE => 0,
+    PNG_FILLER_AFTER => 1,
+    PNG_BACKGROUND_GAMMA_UNKNOWN => 0,
+    PNG_BACKGROUND_GAMMA_SCREEN => 1,
+    PNG_BACKGROUND_GAMMA_FILE => 2,
+    PNG_BACKGROUND_GAMMA_UNIQUE => 3,
     PNG_READ_16_TO_8 => SUPPORTED,
     PNG_GAMMA_THRESHOLD => (PNG_GAMMA_THRESHOLD_FIXED*.00001),
     PNG_CRC_DEFAULT => 0,
@@ -312,6 +333,15 @@ use constant {
     PNG_HANDLE_CHUNK_NEVER => 1,
     PNG_HANDLE_CHUNK_IF_SAFE => 2,
     PNG_HANDLE_CHUNK_ALWAYS => 3,
+    PNG_IO_NONE => 0x0000,
+    PNG_IO_READING => 0x0001,
+    PNG_IO_WRITING => 0x0002,
+    PNG_IO_SIGNATURE => 0x0010,
+    PNG_IO_CHUNK_HDR => 0x0020,
+    PNG_IO_CHUNK_DATA => 0x0040,
+    PNG_IO_CHUNK_CRC => 0x0080,
+    PNG_IO_MASK_OP => 0x000f,
+    PNG_IO_MASK_LOC => 0x00f0,
     PNG_INTERLACE_ADAM7_PASSES => 7,
 };
 
@@ -753,6 +783,30 @@ PNG_GAMMA_sRGB has value 220000.
 
 PNG_GAMMA_LINEAR has value 100000.
 
+=item PNG_FILLER_BEFORE
+
+PNG_FILLER_BEFORE has value 0.
+
+=item PNG_FILLER_AFTER
+
+PNG_FILLER_AFTER has value 1.
+
+=item PNG_BACKGROUND_GAMMA_UNKNOWN
+
+PNG_BACKGROUND_GAMMA_UNKNOWN has value 0.
+
+=item PNG_BACKGROUND_GAMMA_SCREEN
+
+PNG_BACKGROUND_GAMMA_SCREEN has value 1.
+
+=item PNG_BACKGROUND_GAMMA_FILE
+
+PNG_BACKGROUND_GAMMA_FILE has value 2.
+
+=item PNG_BACKGROUND_GAMMA_UNIQUE
+
+PNG_BACKGROUND_GAMMA_UNIQUE has value 3.
+
 =item PNG_READ_16_TO_8
 
 PNG_READ_16_TO_8 has value SUPPORTED.
@@ -925,6 +979,42 @@ PNG_HANDLE_CHUNK_IF_SAFE has value 2.
 
 PNG_HANDLE_CHUNK_ALWAYS has value 3.
 
+=item PNG_IO_NONE
+
+PNG_IO_NONE has value 0x0000.
+
+=item PNG_IO_READING
+
+PNG_IO_READING has value 0x0001.
+
+=item PNG_IO_WRITING
+
+PNG_IO_WRITING has value 0x0002.
+
+=item PNG_IO_SIGNATURE
+
+PNG_IO_SIGNATURE has value 0x0010.
+
+=item PNG_IO_CHUNK_HDR
+
+PNG_IO_CHUNK_HDR has value 0x0020.
+
+=item PNG_IO_CHUNK_DATA
+
+PNG_IO_CHUNK_DATA has value 0x0040.
+
+=item PNG_IO_CHUNK_CRC
+
+PNG_IO_CHUNK_CRC has value 0x0080.
+
+=item PNG_IO_MASK_OP
+
+PNG_IO_MASK_OP has value 0x000f.
+
+=item PNG_IO_MASK_LOC
+
+PNG_IO_MASK_LOC has value 0x00f0.
+
 =item PNG_INTERLACE_ADAM7_PASSES
 
 PNG_INTERLACE_ADAM7_PASSES has value 7.
